netapp_ontap.models.firmware_dqp API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.firmware_dqp`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FirmwareDqpSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FirmwareDqp object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `file_name: str GET`

    Firmware file name

    Example: qual_devices_v3

  `record_count: FirmwareDqpRecordCount GET`

    The record_count field of the firmware_dqp.

  `revision: str GET`

    Firmware revision

    Example: 20200117

  `version: str GET`

    Firmware version

    Example: 3.18